@@ -248,7 +248,7 @@ gnome_program_get_property (GObject *object, guint param_id, GValue *value,
 	break;
     case PROP_GNOME_PATH:
 	if (program->_priv->gnome_path)
-	    g_value_set_string (value, g_strjoinv (":", program->_priv->gnome_path));
+	    g_value_take_string (value, g_strjoinv (":", program->_priv->gnome_path));
 	else
 	    g_value_set_string (value, NULL);
 	break;
@@ -602,6 +602,8 @@ gnome_program_instance_init (GnomeProgram *program)
 
     program->_priv->state = APP_CREATE_DONE;
 
+    program->_priv->prop_enable_sound = TRUE;
+    
     for (i = 0; i < program_modules->len; i++) {
 	GnomeModuleInfo *a_module = g_ptr_array_index (program_modules, i);
 
